==> cvsync-0.24.13.tar.gz: cvsync-0.24.13/common/list.h <==
/*-
 * Copyright (c) 2000-2003 MAEKAWA Masahide <maekawa@cvsync.org>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the author nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

#ifndef __LIST_H__
#define	__LIST_H__

#include "basedef.h"

struct listent;

struct list {
	struct listent	*l_entries, *l_head, *l_tail, *l_freelist;
	void		(*l_destructor)(void *);
};

struct listent {
	struct listent	*le_next, *le_priv;
	void		*le_elm;
	int		le_state;
};

typedef void (*list_destructor)(void *);

#define	list_set_destructor(l, f) \
		__list_set_destructor((l), (list_destructor)(f))

struct list *list_init(void);
void list_destroy(struct list *);
void __list_set_destructor(struct list *, list_destructor);
boolean list_insert_head(struct list *, void *);
boolean list_insert_tail(struct list *, void *);
boolean list_remove(struct list *, struct listent *);
void *list_remove_head(struct list *);
void *list_remove_tail(struct list *);
boolean list_isempty(struct list *);

#endif /* __LIST_H__ */

==> cvsync-0.24.18.tar.gz: cvsync-0.24.18/common/list.h <==
/*-
 * Copyright (c) 2000-2004 MAEKAWA Masahide <maekawa@cvsync.org>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the author nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

#ifndef __LIST_H__
#define	__LIST_H__

struct listent;

struct list {
	struct listent	*l_entries, *l_head, *l_tail, *l_freelist;
	void		(*l_destructor)(void *);
};

struct listent {
	struct listent	*le_next, *le_priv;
	void		*le_elm;
	int		le_state;
};

typedef void (*list_destructor)(void *);

#define	list_set_destructor(l, f) \
		__list_set_destructor((l), (list_destructor)(f))

struct list *list_init(void);
void list_destroy(struct list *);
void __list_set_destructor(struct list *, list_destructor);
bool list_insert_head(struct list *, void *);
bool list_insert_tail(struct list *, void *);
bool list_remove(struct list *, struct listent *);
void *list_remove_head(struct list *);
void *list_remove_tail(struct list *);
bool list_isempty(struct list *);

#endif /* __LIST_H__ */
